#
# spec file for package cadabra2
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cadabra2
Version:        2.2.8
Release:        bp153.1.22
Summary:        A computer algebra system for solving problems in field theory
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://cadabra.science/
Source0:        https://github.com/kpeeters/cadabra2/archive/%{version}.tar.gz
Source1:        %{name}-gtk.appdata.xml
# PATCH-FIX-OPENSUSE add -pthread to CMAKE_CXX_FLAGS (as adivised in https://github.com/potree/PotreeConverter/issues/136) kkaempf@suse.de
Patch1:         cadabra2-add-pthread-to-cxxflags.patch
# PATCH-FIX-UPSTREAM -- https://github.com/kpeeters/cadabra2/commit/71a406f32a654d2037b1d011f44af3fce4d9b50d.patch
Patch2:         Fix-linking-of-cadabra-module.patch
BuildRequires:  appstream-glib
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++ >= 4.9
BuildRequires:  gmp-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_python3-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libuuid-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  python3-matplotlib
BuildRequires:  python3-sympy
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(sqlite3)
Recommends:     %{name}-doc
Recommends:     %{name}-examples

%description
Cadabra2 is a computer algebra system (CAS) designed specifically for
the solution of problems encountered in field theory. It has extensive
functionality for tensor computer algebra, tensor polynomial
simplification including multi-term symmetries, fermions and
anti-commuting variables, Clifford algebras and Fierz transformations,
implicit coordinate dependence, multiple index types and many more.
The input format is a subset of TeX. Both a command-line and a
graphical interface are available.

Key features of Cadabra2:
- Input and output using TeX notation.
- Designed for field-theory problems, with handling of anti-commuting
  and non-commuting objects without special notations for their
  products, gamma matrix algebra, Fierz identities, Dirac conjugation,
  vielbeine, flat and curved, covariant and contravariant indices,
  implicit dependence of tensors on coordinates, partial and covariant
  derivatives...
- Powerful tensor simplification algorithms, not just for mono-term
  symmetries but also for multi-terms symmetries like the Bianchi
  identity, or dimensionally-dependent symmetries like the Schouten
  identity.

%package gui
Summary:        GUI for cadabra2: computer algebra system for problems in field theory
Group:          Productivity/Scientific/Math
Requires:       %{name} = %{version}
Obsoletes:      cadabra < 2.0
Provides:       cadabra = %{version}

%description gui
Cadabra2 is a computer algebra system (CAS) designed specifically for
the solution of problems encountered in field theory.

This package provides the GUI for %{name} and it's desktop menu integration.

%package examples
Summary:        A computer algebra system for solving problems in field theory
Group:          Productivity/Scientific/Math
Requires:       %{name} = %{version}

%description examples
Cadabra2 is a computer algebra system (CAS) designed specifically for
the solution of problems encountered in field theory.

This package provides examples for %{name}.

%package doc
Summary:        A computer algebra system for solving problems in field theory
Group:          Documentation/HTML
Obsoletes:      cadabra-doc < 2.0
Provides:       cadabra-doc = %{version}

%description doc
Cadabra2 is a computer algebra system (CAS) designed specifically for
the solution of problems encountered in field theory.

This package provides html documentation for %{name}.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
rm examples/.gitignore
# Remove timestamps from Doxygen HTML files
echo "HTML_TIMESTAMP = NO" >> config/Doxyfile

%build
%cmake \
  -DCMAKE_MANDIR=%{_mandir} \
  -DPACKAGING_MODE=ON \
  -DINSTALL_LATEX_DIR=%{_datadir}/texmf \
  -DENABLE_FRONTEND=ON \
  -DENABLE_SYSTEM_JSONPP=ON \
  -DENABLE_MATHEMATICA=OFF \
  ..

%cmake_build
cd ..
make %{?_smp_mflags} doc

%install
%cmake_install

%suse_update_desktop_file cadabra2-gtk

# INSTALL APPDATA TO /usr/share/metainfo
install -D -m0644 %{S:1} %{buildroot}%{_datadir}/metainfo/%{name}-gtk.appdata.xml

# Replace "/usr/bin/env python3" hashbang by "/usr/bin/python3"
sed -E -i "s|^#!/usr/bin/env python3|#!/usr/bin/python3|" %{buildroot}%{_bindir}/cadabra2

mkdir -p %{buildroot}%{_datadir}/texmf/tex/latex/cadabra2/
ln %{buildroot}%{_datadir}/cadabra2/latex/* %{buildroot}%{_datadir}/texmf/tex/latex/cadabra2/

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc README.rst
%license doc/license.txt
%{_bindir}/cadabra2cadabra
%{_bindir}/cadabra2latex
%{_bindir}/cadabra-server
%{_bindir}/%{name}
%{_bindir}/%{name}python
%{_bindir}/%{name}html
%{_datadir}/%{name}/
%{_datadir}/texmf
%{_mandir}/man1/cadabra*.1%{?ext_man}

%files gui
%{_bindir}/%{name}-gtk
%{_datadir}/icons/hicolor/*/apps/cadabra2-gtk.*
%{_datadir}/applications/cadabra2-gtk.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*.appdata.xml

%files examples
%doc examples/

%files doc
%doc doxygen/html

%changelog
* Sat Jan  4 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.2.8:
  * More versatile handling of Trace, including sorting using
    cyclic symmetry (Connor).
  * Fixes for combine (Connor).
  * Save command-line history (Connor).
  * Make imported notebooks use the default post_process function.
  * Make unwrap move scalars out of exterior (wedge) products, see
    this Q&A post.
  * Fix bug with indices with accents (github/166).
  * Added a cadabra2latex command to convert notebooks to LaTeX.
  * Fixed issue building with latest Homebrew on macOS.
  * Fixed Windows build issues and add python path settings at
    runtime.
  * Fixed bug with multipliers not reducing to canonical form.
- Add Fix-linking-of-cadabra-module.patch
- Remove timestamps from Doxygen generated HTML files, drop
  obsolete cadabra2-rpmlintrc
- Use system jsoncpp
- Drop conditionals for obsolete distro versions
- Remove lots of unused/obsolete TeX BuildRequires.
* Tue Jun 25 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.7:
  * Added cdb.utils.develop and cdb.relativity.abstract.
  * Added authentication token to all client-server communication.
  * Various extensions to the Trace property.
  * Make property info available from Python (Dominic).
  * Fixed integration by parts with index-less derivatives.
  * Added eliminate_vielbein.
  * Fixed display of lists of sympy expressions.
  * Fixed (finally) UTF8 input for non-English symbols.
- Update to 2.2.6
  * Experimental notebook diff viewer (Dominic).
  * Warn when about to overwrite an existing notebook.
  * Improvements for HiDPI screens especially on macOS.
  * Fix crash in sym/asym.
  * Fix undo/redo crash in notebook when deleting cells.
  * Improvements to the cdb.core.manip package (Dominic).
  * Fix in young_project_tensor.
  * Fix pattern matching for anti-commuting factors.
  * Added explicit_indices to convert expressions with
    implicit indices to their explicit form.
  * Add option to build a Jupyter kernel.
  * Fix bug in split_index (acted on wrong parts of expressions).
  * Fix bug with substitute not checking constraints for
    single-factor patterns.
  * Add partial option to substitute to require that products or sums
    match all terms, not just a partial sum or partial product.
- Refresh cadabra2-add-pthread-to-cxxflags.patch for version
  update, no effective changes.
* Fri Mar 15 2019 Atri B <badshah400@gmail.com>
- Update to version 2.2.5:
  * Interim bug fix release with fixes for upcoming Debian as well
    as the new explicit_indices algorithm.
- Move man files to the correct _mandir.
- Minor cleanups using spec-cleaner.
* Fri Jan 25 2019 badshah400@gmail.com
- Update to version 2.2.4:
  * Minor bug fixes.
- Rebase cadabra2-add-pthread-to-cxxflags.patch for minor changes
  to source CMakeLists.txt file.
- Use make doc instead of running doxygen directly.
- Drop commented out commands to generate PDF documentation.
* Mon Apr 30 2018 guillaume.gardet@opensuse.org
- Disable explicitly mathematica option (fix archs not supported by
  Mathematica, such as AArch64)
* Mon Apr  9 2018 badshah400@gmail.com
- BuildRequires: libboost_date_time-devel instead of
  BuildRequires: libboost_date_time1_66_0-devel, and only for
  openSUSE > 1320; boost-devel in its entirety is already required
  for older versions.
- gcc-c++ >= 4.9 now required.
* Fri Mar 30 2018 badshah400@gmail.com
- Update to version 2.2.0:
  * Experimental support for modifying the expression tree
    directly from Python (see e.g. Fourier transforms).
  * Fix for integration by parts (gh#kpeeters/cadabra2#71)
  * Fix for incorrect conversion to sympy expressions.
  * Optionally build with support for Mathematica scalar backend;
    see map_mma.
  * Many bugfixes for expression display and sympy conversion.
  * Now using pybind instead of boost.python, in preparation for
  * Windows port, and to enable building against Anaconda.
  * Copy/paste of output cells added.
  * New simplify command, which simplifies the scalar parts of
    expressions, and can be switched to use either Sympy or
    Mathematica.
  * Fix to treat derivatives with respect to explicit coordinates
    as scalars in evaluate; see this Q&A post.
  * Fix for failure to flag errors for WeightInherit property.
  * Fixed: vary on single-term expressions
  * (gh#kpeeters/cadabra2#57)
  * Fixed: evaluate with dense factors and no 'values' property on
    indices (gh#kpeeters/cadabra2#68)
- Rename and rebase cadabra2-2.1.7.patch to
  cadabra2-add-pthread-to-cxxflags.patch.
- Add BuildRequires: libboost_date_time1_66_0-devel, new
  dependency with version 2.2.0.
- All python bindings are now required to be installed in
  _datadir.
- New binary cadabra2cadabra.
* Fri Feb  2 2018 stefan.bruens@rwth-aachen.de
- Add a memory _constraints, builds fail with less than 4 GByte
* Sat Jan 27 2018 badshah400@gmail.com
- Disable building LaTeX-based PDF documentation until build
  failures are fixed.
- For the -gui package use post(un) scriptlets only for openSUSE
  <= 1320; for newer openSUSE, these are handled by rpm triggers
  automatically.
* Fri Dec 29 2017 kkaempf@suse.com
- fix build, add -pthread to CMAKE_CXX_FLAGS
  added cadabra2-2.1.7.patch
* Wed Nov 22 2017 badshah400@gmail.com
- Update to version 2.1.7:
  * Another interim release to fix bugs and sort out the build
    process on new distros.
* Thu Nov  2 2017 badshah400@gmail.com
- Update to version 2.1.5:
  * Interim release to get a number of bug fixes out to everyone,
    and to use as basis for binary packages for several new
    distributions.
- Drop cadabra2-cmake-error.patch; fixed upstream.
- Fix Group for cadabra2-doc-pdf: Documentation/PDF doesn't exist,
  use Documentation/Other
- Change hashbang "/usr/bin/env python3" to "/usr/bn/python3".
* Wed Oct 11 2017 badshah400@gmail.com
- Refresh source tarball from upstream: upstream might have pushed
  out a new tarball without changes to the versioning, making the
  source validator service complain about the mismatch.
* Sun Aug  6 2017 badshah400@gmail.com
- Update to version 2.1.5:
  * Interim release with as its main feature the map_sympy command
    which makes it much easier to apply sympy algorithms to
    component expressions.
- Drop cadabra2-include-functional-header.patch; fixed upstream.
* Thu Jul 20 2017 badshah400@gmail.com
- Add an appdata file and install it to /usr/share/metainfo;
  BuildRequires on appstream-glib added.
* Sun Jun 25 2017 badshah400@gmail.com
- Add cadabra2-include-functional-header.patch: Explicitly include
  the <functional> header in core/Functional.hh to fix building on
  openSUSE > 1320; apply without conditionals as it doesn't hurt
  to have this generally.
* Sun Apr 23 2017 badshah400@gmail.com
- BuildRequires: texlive-epstopdf instead of texlive-epstopdf-bin
  to fix build failures on Leap 42.1.
* Sun Apr 23 2017 badshah400@gmail.com
- Update to version 2.1.4:
  * Enable packages to be written using Cadabra notation, instead
    of only pure Python (still experimental).
  * Young tableaux properties Tableau and FilledTableau the
    related algorithm lr_tensor are available again.
  * Sorting Majorana spinors possible again using sort_spinors.
  * Extended rename_dummies with capability to rename indices to
    different set.
  * Make vary work on powers of expressions with dummy indices.
  * Substitution of sub-sums now available (e.g. substitute of
    A+B=C in ex:=A+B+C+D).
  * Improved LaTeX export to make printed notebooks look much
    better.
  * Many improvements to the component engine, in particular for
    handling of derivatives and fractions involving tensors.
  * Better line spacing for line-wrapped equations.
  * Smarter scroll-to-cell behaviour of the notebook.
  * Canonicalising expressions with component values for indices
    now works again.
  * The unwrap algorithm can now be guided about what to unwrap,
    and also knows about spinors and Dirac bars.
  * Experimental support to use Cadabra directly from C++ code, as
    a library (see the c++lib directory).
  * Fixes for using a custom post_process defined as a function
    nested inside another.
  * Rudimentary timing logic, try server.totals();
  * Fixed: pasting text in the notebook sometimes double-pastes.
  * Fixed: split_index does not work properly on left- and
    right-hand side of equations.
  * Fixed: sort_product does not always sort expressions.
  * Fixed: eliminate_metric only acts at top level of an
    expression, should have deep=True by default.
  * Fixed: a bug which would lead to a segfault when using
    deep=True.
- Rebase cadabra2-cmake-error.patch for version update.
- Add %%{name}-rpmlintrc file to suppress warnings about the
  presence of "__DATE__" and/or "__TIME__" in generated html files
  for documentation (%%{name}-doc).
* Tue Jan 17 2017 badshah400@gmail.com
- Initial package.
- Add cadabra2-cmake-error.patch to make sure CMakeLists.txt
  invokes "execute_process" instead of "execute"; fixes build
  failures.
